@@ -1,3 +1,4 @@
+from django.utils.http import urlquote
 from django import forms
 from django.core.mail import EmailMessage
 from django.template.loader import render_to_string
@@ -22,6 +23,9 @@ class ContactFormPlus(forms.Form):
                 if extraField.fieldType == 'CharField':
                     self.fields[slugify(extraField.label)] = forms.CharField(label=extraField.label,
                             initial=extraField.initial,
+                            widget=forms.TextInput(
+                                attrs={'placeholder': extraField.placeholder}
+                            ),
                             required=extraField.required)
                 elif extraField.fieldType == 'BooleanField':
                     self.fields[slugify(extraField.label)] = forms.BooleanField(label=extraField.label,
@@ -30,14 +34,23 @@ class ContactFormPlus(forms.Form):
                 elif extraField.fieldType == 'EmailField':
                     self.fields[slugify(extraField.label)] = forms.EmailField(label=extraField.label,
                             initial=extraField.initial,
+                            widget=forms.TextInput(
+                                attrs={'placeholder': extraField.placeholder}
+                            ),
                             required=extraField.required)
                 elif extraField.fieldType == 'DecimalField':
                     self.fields[slugify(extraField.label)] = forms.DecimalField(label=extraField.label,
                             initial=extraField.initial,
+                            widget=forms.TextInput(
+                                attrs={'placeholder': extraField.placeholder}
+                            ),
                             required=extraField.required)
                 elif extraField.fieldType == 'FloatField':
                     self.fields[slugify(extraField.label)] = forms.FloatField(label=extraField.label,
                             initial=extraField.initial,
+                            widget=forms.TextInput(
+                                attrs={'placeholder': extraField.placeholder}
+                            ),
                             required=extraField.required)
                 elif extraField.fieldType == 'FileField': 
                     self.fields[slugify(extraField.label)] = forms.FileField(label=extraField.label,
@@ -49,16 +62,32 @@ class ContactFormPlus(forms.Form):
                             required=extraField.required)
                 elif extraField.fieldType == 'IntegerField':
                     self.fields[slugify(extraField.label)] = forms.IntegerField(label=extraField.label,
+                            initial=extraField.initial,
+                            widget=forms.TextInput(
+                                attrs={'placeholder': extraField.placeholder}
+                            ),
+                            required=extraField.required)
+                elif extraField.fieldType == 'DateField':
+                    self.fields[slugify(extraField.label)] = forms.DateField(label=extraField.label,
+                            initial=extraField.initial,
+                            required=extraField.required)
+                elif extraField.fieldType == 'DateTimeField':
+                    self.fields[slugify(extraField.label)] = forms.DateTimeField(label=extraField.label,
                             initial=extraField.initial,
                             required=extraField.required)
                 elif extraField.fieldType == 'IPAddressField':
                     self.fields[slugify(extraField.label)] = forms.IPAddressField(label=extraField.label,
                             initial=extraField.initial,
+                            widget=forms.TextInput(
+                                attrs={'placeholder': extraField.placeholder}
+                            ),
                             required=extraField.required)
                 elif extraField.fieldType == 'auto_Textarea':
                     self.fields[slugify(extraField.label)] = forms.CharField(label=extraField.label,
                             initial=extraField.initial,
-                            widget=forms.Textarea,
+                            widget=forms.Textarea(
+                                attrs={'placeholder': extraField.placeholder}
+                            ),
                             required=extraField.required)
                 elif extraField.fieldType == 'auto_hidden_input':
                     self.fields[slugify(extraField.label)] = forms.CharField(label=extraField.label,
@@ -95,6 +124,9 @@ class ContactFormPlus(forms.Form):
                     self.fields[slugify(extraField.label)] = forms.CharField(
                         label=extraField.label,
                         initial=extraField.initial,
+                        widget=forms.Textarea(
+                            attrs={'placeholder': extraField.placeholder}
+                        ),
                         required=extraField.required,
                         validators=get_validators())
 
@@ -115,11 +147,12 @@ class ContactFormPlus(forms.Form):
                     if settings.MEDIA_URL.startswith("http"):
                         value = "%s%s" % (settings.MEDIA_URL, val)
                     else:
-                        value = "http://%s%s%s" % (current_site, settings.MEDIA_URL, val)
+                        value = "http://%s%s%s" % (current_site, settings.MEDIA_URL, urlquote(val))
                 ordered_dic_list.append({field.label: value})
 
         # Automatically match reply-to email address in form
         tmp_headers = {}
+        cc_list = []
         try:
             reply_email_label = getattr(settings, 'CONTACT_PLUS_REPLY_EMAIL_LABEL', None)
             if reply_email_label is not None:
@@ -127,12 +160,22 @@ class ContactFormPlus(forms.Form):
         except:
             pass
 
+        try:
+            cc_address_label = getattr(settings, 'CONTACT_PLUS_REPLY_EMAIL_LABEL', None)
+            cc_address = self.cleaned_data.get(cc_address_label, None)
+            send_copy = getattr(settings, 'CONTACT_PLUS_SEND_COPY_TO_REPLY_EMAIL', False)
+            if cc_address and send_copy:
+                cc_list.append(cc_address)
+        except:
+            pass
+
         email_message = EmailMessage(
             subject=instance.email_subject,
             body=render_to_string("cmsplugin_contact_plus/email.txt", {'data': self.cleaned_data,
                                                                       'ordered_data': ordered_dic_list,
                                                                       'instance': instance,
                                                                       }),
+            cc=cc_list,
             from_email=getattr(settings, 'CONTACT_PLUS_FROM_EMAIL', settings.DEFAULT_FROM_EMAIL),
             to=[recipient_email, ],
             headers=tmp_headers,
